/*
==============================================================================
* PC Suite Connectivity API 1.1
*
Filename    : CONAFileSystem.h
Description : File System functions
Version     : 1.1

Copyright (c) 2005 Nokia Corporation.
This software, including but not limited to documentation and any related 
computer programs ("Software"), is protected by intellectual property rights 
of Nokia Corporation and/or its licensors. All rights are reserved. By using 
the Software you agree to the terms and conditions hereunder. If you do not 
agree you must cease using the software immediately.
Reproducing, disclosing, modifying, translating, or distributing any or all 
of the Software requires the prior written consent of Nokia Corporation. 
Nokia Corporation retains the right to make changes to the Software at any 
time without notice.

A copyright license is hereby granted to use of the Software to make, publish, 
distribute, sub-license and/or sell new Software utilizing this Software. 
The Software may not constitute the primary value of any new software utilizing 
this software. No other license to any other intellectual property rights of 
Nokia or a third party is granted. 

THIS SOFTWARE IS PROVIDED "AS IS" WITHOUT WARRANTY OF ANY KIND, EITHER EXPRESS 
OR IMPLIED, INCLUDING WITHOUT LIMITATION, ANY WARRANTY OF NON-INFRINGEMENT, 
MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. IN NO EVENT SHALL
NOKIA CORPORATION BE LIABLE FOR ANY DIRECT, INDIRECT, SPECIAL, INCIDENTAL, 
OR CONSEQUENTIAL LOSS OR DAMAGES, INCLUDING BUT NOT LIMITED TO, LOST PROFITS 
OR REVENUE, LOSS OF USE, COST OF SUBSTITUTE PROGRAM, OR LOSS OF DATA OR EQUIPMENT 
ARISING OUT OF THE USE OR INABILITY TO USE THE MATERIAL, EVEN IF 
NOKIA CORPORATION HAS BEEN ADVISED OF THE LIKELIHOOD OF SUCH DAMAGES OCCURRING. 
==============================================================================
*/

#ifndef _CONAFILESYSTEM_H_
#define _CONAFILESYSTEM_H_


///////////////////////////////////////////////////////////
// ConnectivityAPI File System functions
///////////////////////////////////////////////////////////

	//=========================================================
	// CONAOpenFS
	//
	// Description:
	//	CONAOpenFS opens a file system (FS) connection to the target 
	//	device. The function sets the FS Connection handle, which 
	//	identifies different client connections. It will be placed 
	//	into the given pointer. 
	//	
	//	If the media type is CONAPI_MEDIA_ALL, the System selects 
	//	the used media type automatically by applying the following rule:
	//	If there is an open FS connection to the device, it will be used. 
	//	Otherwise the System tries to open the FS connection in the 
	//	following order: USB, Serial, Irda and BT (if the device is 
	//	connected via medias). The function also sets the DeviceID, 
	//	which can be used to identify the used media type.
	//	
	//	If the Serial Number is an empty string, the function tries to 
	//	open the FS connection by using the pdwDeviceID parameter. The 
	//	pdwMedia parameter is not used in the exemplary case.
	//
	// Parameters:
	//	pstrSerialNumber [in]     The device's serial number, which must be set.
	//	pdwMedia		 [in,out] In: Media type, which defines the target
	//								 media for the Device's FS connection.
	//							  Out:If the value is CONAPI_MEDIA_ALL, the 
	//								 target media is selected automatically 
	//								 and the used media type is returned.
	//	phFSHandle		 [out]	  Handle to the opened FS connection
	//	pdwDeviceID		 [in,out] In: Device ID. Used only when the Serial 
	//								 number is empty string.
	//							  Out: Returned Device ID value of the connected device.
	//
	// Return values:
	// CONA_OK
	// ECONA_DEVICE_NOT_FOUND
	// ECONA_NO_CONNECTION_VIA_MEDIA
	// ECONA_NOT_SUPPORTED_DEVICE
	// ECONA_CONNECTION_FAILED
	// ECONA_CONNECTION_BUSY
	// ECONA_CONNECTION_LOST
	// ECONA_FAILED_TIMEOUT
	// ECONA_INVALID_POINTER
	// ECONA_NOT_INITIALIZED
	// ECONA_NOT_SUPPORTED_MANUFACTURER
	// ECONA_NOT_ENOUGH_MEMORY
	// ECONA_UNKNOWN_ERROR
	//
		CONN_API CONAOpenFS( const WCHAR* pstrSerialNumber,
							 DWORD*	pdwMedia,
							 FSHANDLE* phFSHandle,
							 DWORD*	pdwDeviceID );
	//=========================================================

	//=========================================================
	// CONACloseFS
	//
	// Description:
	//	CONACloseFS closes the given file system connection.
	//
	// Parameters:
	//	hFSHandle	[in] Existing file system handle
	//
	// Return values:
	//	CONA_OK
	//	ECONA_INVALID_HANDLE
	//	ECONA_NOT_INITIALIZED
	//	ECONA_UNKNOWN_ERROR
	//
		CONN_API CONACloseFS( FSHANDLE hFSHandle );
	//=========================================================

	//=========================================================
	// CONARegisterFSNotifyCallback
	//
	// Description:
	// CONARegisterFSNotifyCallback registers or unregisters the 
	// callback function for the file functions' status notifications.
	// 
	// During file operations, the Connectivity API calls this function 
	// with the parameter's state (0-100%), connection handle, and 
	// operation code.

	//
	// Parameters:
	//	hFSHandle	[in] File System handle
	//	dwState		[in] Register flag:
	//					  CONAPI_REGISTER:   Registers a callback function
	//					  CONAPI_UNREGISTER: Unregisters a callback function
	//	pFSNotify	[in] Pointer to a function.
	//
	// Return values:
	//	CONA_OK
	//	ECONA_INVALID_HANDLE
	//	ECONA_INVALID_POINTER
	//	ECONA_INVALID_PARAMETER
	//	ECONA_NOT_INITIALIZED
	//	ECONA_UNKNOWN_ERROR
	//
		CONN_API CONARegisterFSNotifyCallback( FSHANDLE hFSHandle,
											   DWORD	 dwState,
											   PFN_CONA_FS_CALLBACK pFSNotify );
	//=========================================================

	//=========================================================
	// CONARefreshDeviceMemoryValues
	//
	// Description:
	//	CONARefreshDeviceMemoryValues refreshes the memory values 
	// from the device. The function caches the memory values, so 
	// it must be called if it is required to get the latest information.
	//
	// Parameters:
	//	hFSHandle	[in] File system handle
	//
	// Return values:
	//	CONA_OK
	//	ECONA_INVALID_HANDLE
	//	ECONA_CONNECTION_BUSY
	//	ECONA_CONNECTION_LOST
	//	ECONA_INVALID_DATA_DEVICE
	//	ECONA_CANCELLED
	//	ECONA_FAILED_TIMEOUT
	//	ECONA_UNKNOWN_ERROR_DEVICE
	//	ECONA_NOT_INITIALIZED
	//	ECONA_UNKNOWN_ERROR
	//
		CONN_API CONARefreshDeviceMemoryValues( FSHANDLE hFSHandle );
	//=========================================================

	//=========================================================
	// CONAGetMemoryTypes
	//
	// Description:
	// CONAGetMemoryTypes receives all memory types that currently 
	// exist in the device. The format of its string is 
	// "Memory type string" comma "next Memory type string". An 
	// example of a string is "DEV,MMC,APPL". 
	// 
	// The device can include different memory types. For example, 
	// the memory types can be "DEV" (device memory), "MMC" 
	// (memory card), or "APPL" (device special memory).	
	//
	// Parameters:
	//	hFSHandle			[in]  File system handle.
	//	ppstrMemoryTypes	[out] Memory types.
	//
	// Return values:
	//	CONA_OK
	//	ECONA_INVALID_HANDLE
	//	ECONA_INVALID_POINTER
	//	ECONA_NOT_SUPPORTED_DEVICE
	//	ECONA_NOT_INITIALIZED
	//	ECONA_UNKNOWN_ERROR
	//
		CONN_API CONAGetMemoryTypes( FSHANDLE hFSHandle, WCHAR** ppstrMemoryTypes );
	//=========================================================
	
	//=========================================================
	// CONAGetMemoryValues
	//
	// Description:
	//	CONAGetDeviceMemory returns info about the given device memory type.
	//
	// Parameters:
	//	hFSHandle		[in]  File System handle.
	//	pstrMemoryType	[in]  Inquired device memory.E.g. "DEV", "MMC", 
	//                        or "APPL".If the value is NULL, the used value is "DEV".
	//	pdlFree			[out] Pointer to the variable receiving the 
	//						  information on the amount of free memory.
	//						  If not available, the value is -1.
	//	pdlTotal		[out] Pointer to the variable receiving 
	//						  the information on the total memory.
	//						  If not available, the value is -1.
	//	pdlUsed			[out] Pointer to the variable receiving 
	//						  the information on the used memory.
	//						  If not available, the value is -1.
	//
	// Return values:
	//	CONA_OK
	//	ECONA_INVALID_HANDLE
	//	ECONA_INVALID_POINTER
	//	ECONA_INVALID_PARAMETER
	//	ECONA_NOT_SUPPORTED_DEVICE
	//	ECONA_NOT_INITIALIZED
	//	ECONA_UNKNOWN_ERROR
	//
		CONN_API CONAGetMemoryValues( FSHANDLE hFSHandle,
									  const WCHAR*	pstrMemoryType,
									  __int64* pdlFree, 
									  __int64* pdlTotal,
									  __int64* pdlUsed );
	//=========================================================

	//=========================================================
	// CONASetCurrentFolder
	//
	// Description:
	// CONASetCurrentFolder sets the device's current folder. All 
	// file and folder operations with a relative path reference 
	// will use this value. After the connection is established, 
	// the default value is the device's root-folder. Only backslashes 
	// ("\") are allowed folder separators.
	// 
	// Any other FS operation does not change the current folder. 
	// If CONASetCurrentFolder fails, the currect folder is not changed. 
	//
	// Parameters:
	//	hFSHandle	[in] File System handle
	//	pstrPath	[in] Name of the new current folder. Its value may 
	//					 be a relative or absolute reference. If the 
	//					 absolute path is used, the first two characters 
	//					 must be backslashes "\\". If you set the current 
	//					 folder to the root-folder, the path must include 
	//					 only two backslash characters "\\".
	//					 If the current folder is required to move sub folder, 
	//					 the path must not include any backslashes.
	//					 If the current folder is required to change the 
	//					 parent folder, the first two characters must be dots
	//					 and the third character must be a backslash "..\". 
	//
	// Return values:
	//	CONA_OK
	//	ECONA_INVALID_HANDLE
	//	ECONA_INVALID_PARAMETER
	//	ECONA_CONNECTION_BUSY
	//	ECONA_CONNECTION_LOST
	//	ECONA_CURRENT_FOLDER_NOT_FOUND
	//	ECONA_FOLDER_NOT_FOUND
	//	ECONA_FOLDER_PATH_TOO_LONG
	//	ECONA_FOLDER_NAME_INVALID_DEVICE
	//	ECONA_FOLDER_NO_PERMISSION
	//	ECONA_CANCELLED
	//	ECONA_FAILED_TIMEOUT
	//	ECONA_UNKNOWN_ERROR_DEVICE
	//	ECONA_NOT_INITIALIZED
	//	ECONA_UNKNOWN_ERROR
	//
		CONN_API CONASetCurrentFolder( FSHANDLE hFSHandle, const WCHAR* pstrPath );
	//=========================================================

	//=========================================================
	// CONAGetCurrentFolder
	//
	// Description:
	// CONAGetCurrentFolder returns the current folder, which is 
	// set by using the CONASetCurrentFolder function.
	//
	// Parameters:
	//	hFSHandle		[in]  File System handle
	//	ppstrPath		[out] Pointer to the WCHAR receiving 
	//						  the current folder.
	//	
	//
	// Return values:
	//	CONA_OK
	//	ECONA_INVALID_HANDLE
	//	ECONA_INVALID_POINTER
	//	ECONA_CONNECTION_LOST
	//	ECONA_CANCELLED
	//	ECONA_FAILED_TIMEOUT
	//	ECONA_NOT_INITIALIZED
	//	ECONA_UNKNOWN_ERROR	
	//
		CONN_API CONAGetCurrentFolder( FSHANDLE hFSHandle, WCHAR**  ppstrPath );
	//=========================================================

	//=========================================================
	// CONAFindBegin
	//
	// Description:
	// CONAFindBegin starts find files and subfolders from currect 
	// folder or target path. If target path is used, path must be 
	// absolute path.Find option:
	// CONA_FIND_USE_CACHE	  Use cache if it is available.
	//
	// Parameters:
	//	hFSHandle		[in]  File System handle
	//	dwFindOptions	[in]  Find options:If CONA_FIND_USE_CACHE option
	//						  is not used, value must be 0.
	//	pFileHandle		[out] Pointer to find handle
	//	pstrTargetPath	[in]  Target path. If the path is NULL, 
	//						  the current folder is used 
	//
	// Return values:
	//	CONA_OK
	//	ECONA_INVALID_HANDLE
	//	ECONA_INVALID_PARAMETER
	//	ECONA_INVALID_POINTER
	//	ECONA_CONNECTION_BUSY
	//	ECONA_CONNECTION_LOST
	//	ECONA_INVALID_DATA_DEVICE
	//	ECONA_CURRENT_FOLDER_NOT_FOUND
	//	ECONA_CANCELLED
	//	ECONA_FAILED_TIMEOUT
	//	ECONA_UNKNOWN_ERROR_DEVICE
	//	ECONA_NOT_INITIALIZED
	//  ECONA_NOT_ENOUGH_MEMORY
	//	ECONA_UNKNOWN_ERROR
	//	ECONA_FOLDER_PATH_TOO_LONG
	//	ECONA_FOLDER_NAME_INVALID_DEVICE
	//	ECONA_FOLDER_NO_PERMISSION
	//
		CONN_API CONAFindBegin( FSHANDLE	hFSHandle,
								DWORD		dwFindOptions,
								FINDHANDLE* phFindHandle,
								const WCHAR* pstrTargetPath );
	//=========================================================

	//=========================================================
	// CONAFindNextFolder
	//
	// Description:
	// CONAFindNextFolder returns the folder information for one 
	// folder and continues the search to the next folder. The 
	// folder information is returned with the CONAPI_FOLDER_INFO 
	// structure. The allocated memory MUST be freed by calling 
	// the CONAFreeFolderInfoStructure function.
	//
	// Parameters:
	//	hFindHandle		[in]  Find handle
	//	pFolderInfo		[out] Pointer to the folder's info struct.
	//
	// Return values:
	//	CONA_OK
	//	ECONA_ALL_LISTED
	//	ECONA_INVALID_HANDLE
	//	ECONA_INVALID_POINTER
	//	ECONA_NOT_INITIALIZED
	//	ECONA_UNKNOWN_ERROR
	//
		CONN_API CONAFindNextFolder( FINDHANDLE hFindHandle, 
									 LPCONAPI_FOLDER_INFO pFolderInfo );	
	//=========================================================

	//=========================================================
	// CONAFindNextFile
	//
	// Description:
	// CONAFindNextFile returns file information for one file, 
	// and continues the search to the next file. File information 
	// is returned with the CONAPI_FILE_INFO structure. Allocated 
	// memory MUST be freed by calling CONAFreeFileInfoStructure function.
	//
	// Parameters:
	//	hFindHandle		[in]  Find handle
	//	pFileInfo		[out] Pointer to the file's info struct.
	//
	// Return values:
	//	CONA_OK
	//	ECONA_ALL_LISTED
	//	ECONA_INVALID_HANDLE
	//	ECONA_INVALID_POINTER
	//	ECONA_NOT_INITIALIZED
	//	ECONA_UNKNOWN_ERROR
	//
		CONN_API CONAFindNextFile( FINDHANDLE hFindHandle, LPCONAPI_FILE_INFO pFileInfo );
	//=========================================================

	//=========================================================
	// CONAFindEnd
	//
	// Description:
	// CONAFindEnd closes find handle.
	//
	//
	// Parameters:
	//	hFindHandle		[in]  Find handle
	//
	// Return values:
	//	CONA_OK
	//	ECONA_INVALID_HANDLE
	//
		CONN_API CONAFindEnd( FINDHANDLE hFindHandle );
	//=========================================================

	//=========================================================
	// CONACreateFolder
	//
	// Description:
	// CONACreateFolder creates a new folder onto the device. 
	// The function fails if the folder already exists on the device.
	//
	// Parameters:
	//	hFSHandle		[in] File System handle
	//	pstrFolderName	[in] New folder name string
	//	pstrTargetPath	[in] Target path. If path is NULL, current 
	//						 folder is used. 
	//
	// Return values:
	//	CONA_OK
	//	ECONA_INVALID_HANDLE
	//	ECONA_INVALID_PARAMETER
	//	ECONA_CONNECTION_BUSY
	//	ECONA_CONNECTION_LOST
	//	ECONA_INVALID_DATA_DEVICE
	//	ECONA_CURRENT_FOLDER_NOT_FOUND
	//	ECONA_FOLDER_PATH_TOO_LONG
	//	ECONA_FOLDER_NAME_INVALID_DEVICE
	//	ECONA_FOLDER_ALREADY_EXIST
	//	ECONA_FOLDER_NO_PERMISSION
	//	ECONA_CANCELLED
	//	ECONA_FAILED_TIMEOUT
	//	ECONA_UNKNOWN_ERROR_DEVICE
	//	ECONA_NOT_INITIALIZED
	//	ECONA_UNKNOWN_ERROR
	//
		CONN_API CONACreateFolder(	FSHANDLE hFSHandle, 
									const WCHAR* pstrFolderName, 
									const WCHAR* pstrTargetPath);
	//=========================================================

	//=========================================================
	// CONADeleteFolder
	//
	// Description:
	// CONADeleteFolder deletes a folder from the device. This 
	// function does not delete the folder if the folder includes 
	// any subfolder(s)! Only an empty folder and a folder that 
	// contains files can be deleted. If the folder does not include 
	// a DELETE-permission, the function fails.
	//
	// Note: No rollback option! Deleted data cannot be restored!
	//
	// Parameters:
	//	hFSHandle		[in] File System handle
	//	pstrFolderName	[in] Folder name string
	//	dwDeleteOptions	[in] Delete options. Possible values: 
	//			CONA_DELETE_FOLDER_EMPTY:		Only an empty folder can be deleted.
	//			CONA_DELETE_FOLDER_WITH_FILES:  Only a folder that contains file(s) can be deleted.
	//	pstrTargetPath	[in] Target path. If path is NULL, current
	//						 folder is used.  
	//
	// Return values:
	//	CONA_OK
	//	ECONA_INVALID_HANDLE
	//	ECONA_INVALID_PARAMETER
	//	ECONA_CONNECTION_BUSY
	//	ECONA_CONNECTION_LOST
	//	ECONA_INVALID_DATA_DEVICE
	//	ECONA_CURRENT_FOLDER_NOT_FOUND
	//	ECONA_FOLDER_PATH_TOO_LONG
	//	ECONA_FOLDER_NOT_FOUND
	//	ECONA_FOLDER_NOT_EMPTY
	//	ECONA_FOLDER_NO_PERMISSION
	//	ECONA_CANCELLED
	//	ECONA_FAILED_TIMEOUT
	//	ECONA_UNKNOWN_ERROR_DEVICE
	//	ECONA_NOT_INITIALIZED
	//	ECONA_UNKNOWN_ERROR
	//
		CONN_API CONADeleteFolder(	FSHANDLE hFSHandle, 
									const WCHAR* pstrFolderName,
									DWORD dwDeleteOptions,
									const WCHAR* pstrTargetPath);
	//=========================================================

	//=========================================================
	// CONARenameFolder
	//
	// Description:
	// CONARenameFolder renames a folder on the device. Only an 
	// empty folder can be renamed at the moment.

	//
	// Parameters:
	//	hFSHandle		  [in] File System handle
	//	pstrFolderName	  [in] Folder name string.
	//	pstrFolderNameNew [in] Folder's new name string.
	//	pstrTargetPath	  [in] Target path. If the path is NULL, 
	//                         current folder is used. 
	//
	// Return values:
	//	CONA_OK
	//	ECONA_INVALID_HANDLE
	//	ECONA_INVALID_PARAMETER
	//	ECONA_CONNECTION_BUSY
	//	ECONA_CONNECTION_LOST
	//	ECONA_INVALID_DATA_DEVICE
	//	ECONA_CURRENT_FOLDER_NOT_FOUND
	//  ECONA_FOLDER_PATH_TOO_LONG
	//	ECONA_FOLDER_ALREADY_EXIST
	//	ECONA_FOLDER_NOT_FOUND
	//	ECONA_FOLDER_NOT_EMPTY
	//	ECONA_FOLDER_NO_PERMISSION
	//	ECONA_CANCELLED
	//	ECONA_FAILED_TIMEOUT
	//	ECONA_UNKNOWN_ERROR_DEVICE
	//	ECONA_NOT_INITIALIZED
	//	ECONA_UNKNOWN_ERROR
	//
		CONN_API CONARenameFolder(	FSHANDLE hFSHandle, 
									const WCHAR* pstrFolderName, 
									const WCHAR* pstrFolderNameNew, 
									const WCHAR* pstrTargetPath);
	//=========================================================

	//=========================================================
	// CONAGetFileInfo
	//
	// Description:
	// CONAGetFileInfo returns the file data in CONAPI_FILE_INFO 
	// structure. If the cached file data is available that will be used. 
	// Allocated memory MUST be freed by calling the 
	// CONAFreeFileInfoStructure function.
	//
	// Parameters:
	//	hFSHandle		[in]  File System handle
	//	pstrFileName	[in]  File name 
	//	pFileInfo		[out] Pointer to the structure receiving
	//						  the file information.
	//	pstrTargetPath	[in]  Target path. If the path is NULL, 
	//						  the current folder is used.  
	//
	// Return values:
	//	CONA_OK
	//	ECONA_INVALID_HANDLE
	//	ECONA_INVALID_PARAMETER
	//	ECONA_INVALID_POINTER
	//	ECONA_CONNECTION_BUSY
	//	ECONA_CONNECTION_LOST
	//	ECONA_INVALID_DATA_DEVICE
	//	ECONA_CURRENT_FOLDER_NOT_FOUND
	//	ECONA_CANCELLED
	//	ECONA_FAILED_TIMEOUT
	//	ECONA_UNKNOWN_ERROR_DEVICE
	//	ECONA_NOT_INITIALIZED
	//	ECONA_NOT_ENOUGH_MEMORY
	//	ECONA_UNKNOWN_ERROR
	//	ECONA_FOLDER_PATH_TOO_LONG
	//	ECONA_FOLDER_NAME_INVALID_DEVICE
	//	ECONA_FOLDER_NO_PERMISSION
	//
		CONN_API CONAGetFileInfo( FSHANDLE hFSHandle, 
								  const WCHAR* pstrFileName, 
								  LPCONAPI_FILE_INFO pFileInfo, 
								  const WCHAR* pstrTargetPath);	
	//=========================================================

	//=========================================================
	// CONADeleteFile
	//
	// Description:
	//	CONADeleteFile deletes a file from the device's folder. 
	//	Note: No rollback option! Deleted data cannot be restored!
	//
	// Parameters:
	//	hFSHandle		[in] File System handle
	//	pstrFileName	[in] File name 
	//	pstrTargetPath	[in] Target path. If the path is NULL, 
	//                       the current folder is used.  
	//
	// Return values:
	//	CONA_OK
	//	ECONA_INVALID_HANDLE
	//	ECONA_INVALID_PARAMETER
	//	ECONA_CONNECTION_BUSY
	//	ECONA_CONNECTION_LOST
	//	ECONA_INVALID_DATA_DEVICE
	//	ECONA_CURRENT_FOLDER_NOT_FOUND
	//	ECONA_FILE_NOT_FOUND
	//	ECONA_FILE_NO_PERMISSION
	//	ECONA_CANCELLED
	//	ECONA_FAILED_TIMEOUT
	//	ECONA_UNKNOWN_ERROR_DEVICE
	//	ECONA_NOT_INITIALIZED
	//	ECONA_UNKNOWN_ERROR
	//
		CONN_API CONADeleteFile( FSHANDLE hFSHandle, 
								 const WCHAR* pstrFileName, 
								 const WCHAR* pstrTargetPath);
	//=========================================================

	//=========================================================
	// CONAMoveFile
	//
	// Description:
	//	CONAMoveFile copy file to target folder on PC or Device 
	//  from Device or PC source folder and removes a file from 
	//  the source folder on the Device or PC. 
	//
	//  Note: No rollback option! If an error occurs during the
	//	execution of the command (e.g. connection lost: file from 
	//  target folder will be deleted if it is changed), the 
	//  changes that have been already made are not cancelled.
	//  
	//  If the current folder is used, the path to the device's 
	//  source or target folder does not need to be set. PC side 
	//  path can also include the target/source file name. If path 
	//  to device's target or source folder is given, it cannot 
	//  include file name.
	//  
	//
	// Parameters:
	//	hFSHandle		[in] File System handle
	//	dwOptions		[in] Direction options:
	//		CONA_DIRECT_PHONE_TO_PC: Moves a file from the device to the PC.
	//		CONA_DIRECT_PC_TO_PHONE: Moves a file from the PC to the 
	//						 Other options:
	//		CONA_OVERWRITE:  Moves the file even if the target folder contains 
	//						 a file of the same name. The file will be replaced.
	//	pstrFileName	[in] File name. Can be NULL, if file name 
	//						 is given with PC path. 
	//	pstrSourcePath	[in] Source folder path. Value can include
	//						 also the source file name, if option
	//						 CONA_DIRECT_PC_TO_PHONE is used (PC path)
	//	pstrTargetPath	[in] Target folder path. Value can include  
	//						 also the target file name, if option 
	//						 CONA_DIRECT_PHONE_TO_PC is used (PC path)
	//
	// Return values:
	//	CONA_OK
	//	ECONA_INVALID_HANDLE
	//	ECONA_INVALID_PARAMETER
	//	ECONA_CONNECTION_BUSY
	//	ECONA_CONNECTION_LOST
	//	ECONA_INVALID_DATA_DEVICE
	//	ECONA_MEMORY_FULL
	//	ECONA_CURRENT_FOLDER_NOT_FOUND
	//	ECONA_FOLDER_PATH_TOO_LONG
	//	ECONA_FOLDER_NOT_FOUND
	//	ECONA_FILE_TOO_BIG_DEVICE
	//	ECONA_FILE_NAME_INVALID
	//	ECONA_FILE_NAME_TOO_LONG
	//	ECONA_FILE_NOT_FOUND
	//	ECONA_FILE_ALREADY_EXIST
	//	ECONA_FILE_COPYRIGHT_PROTECTED
	//	ECONA_FILE_NO_PERMISSION
	//	ECONA_FOLDER_NO_PERMISSION
	//	ECONA_FILE_NO_PERMISSION_ON_PC
	//  ECONA_FOLDER_NO_PERMISSION_ON_PC
	//	ECONA_FILE_BUSY
	//	ECONA_FILE_TYPE_NOT_SUPPORTED
	//	ECONA_FILE_EXIST
	//	ECONA_CANCELLED
	//	ECONA_FAILED_TIMEOUT
	//	ECONA_NOT_SUPPORTED_DEVICE
	//	ECONA_UNKNOWN_ERROR_DEVICE
	//	ECONA_NOT_INITIALIZED
	//	ECONA_NOT_ENOUGH_MEMORY
	//	ECONA_UNKNOWN_ERROR
	//
		CONN_API CONAMoveFile(	FSHANDLE hFSHandle,
								DWORD dwOptions,
								const WCHAR* pstrFileName,
								const WCHAR* pstrSourcePath,
								const WCHAR* pstrTargetPath);
	//=========================================================

	//=========================================================
	// CONACopyFile
	//
	// Description:
	//	CONACopyFile copy file to target folder on PC or Device 
	//	from Device or PC source folder 
	//	
	//	If current folder is used, path to device folder do not 
	//	need to set. Current folder can be used for source and 
	//	target location. PC side path can also include the 
	//	target/source file name. If path to device's target or 
	//	source folder is given, it cannot include file name.
	//	
	//  Note: No rollback option! If an error occurs during the
	//	execution of the command (e.g. connection lost: file from 
	//  target folder will be deleted if it is changed), the 
	//  changes that have been already made are not cancelled.
	//	
	//
	// Parameters:
	//	hFSHandle		[in] File System handle
	//	dwOptions		[in] Copy options, Direction options:
	//			CONA_DIRECT_PC_TO_PHONE: Copies a file from the PC onto the device.
	//			CONA_DIRECT_PHONE_TO_PC: Copies a file from the device onto the PC.
	//						Other options:
	//			CONA_RENAME: Renames the file if it already exists in the target folder.
	//			CONA_OVERWRITE: Overwrites the file if it already exists in the target folder.
	//	pstrFileName	[in] File name. Can be NULL, if file name 
	//						 is given with PC path. 
	//	pstrSourcePath	[in] Source folder path. Value can include
	//						 also the source file name, if option
	//						 CONA_DIRECT_PC_TO_PHONE is used (PC path)
	//	pstrTargetPath	[in] Target folder path. Value can include  
	//						 also the target file name, if option 
	//						 CONA_DIRECT_PHONE_TO_PC is used (PC path)
	//
	// Return values:
	//	CONA_OK
	//	ECONA_INVALID_HANDLE
	//	ECONA_INVALID_PARAMETER
	//	ECONA_CONNECTION_BUSY
	//	ECONA_CONNECTION_LOST
	//	ECONA_INVALID_DATA_DEVICE
	//	ECONA_MEMORY_FULL
	//	ECONA_CURRENT_FOLDER_NOT_FOUND
	//	ECONA_FOLDER_PATH_TOO_LONG
	//	ECONA_FOLDER_NOT_FOUND
	//	ECONA_FILE_TOO_BIG_DEVICE
	//	ECONA_FILE_NAME_INVALID
	//	ECONA_FILE_NAME_TOO_LONG
	//	ECONA_FILE_NOT_FOUND
	//	ECONA_FILE_ALREADY_EXIST
	//	ECONA_FILE_COPYRIGHT_PROTECTED
	//	ECONA_FILE_NO_PERMISSION
	//	ECONA_FOLDER_NO_PERMISSION
	//	ECONA_FILE_NO_PERMISSION_ON_PC
	//	ECONA_FOLDER_NO_PERMISSION_ON_PC
	//	ECONA_FILE_BUSY
	//	ECONA_FILE_TYPE_NOT_SUPPORTED
	//	ECONA_FILE_NO_PERMISSION_ON_PC
	//	ECONA_CANCELLED
	//	ECONA_FAILED_TIMEOUT
	//	ECONA_NOT_SUPPORTED_DEVICE
	//	ECONA_UNKNOWN_ERROR_DEVICE
	//	ECONA_NOT_INITIALIZED
	//	ECONA_NOT_ENOUGH_MEMORY
	//	ECONA_UNKNOWN_ERROR
	//
		CONN_API CONACopyFile(	FSHANDLE hFSHandle,
								DWORD dwOptions,
								const WCHAR* pstrFileName,
								const WCHAR* pstrSourcePath,
								const WCHAR* pstrTargetPath);
	//=========================================================

	//=========================================================
	// CONARenameFile
	//
	// Description:
	//	CONARenameFile renames the given file.
	//
	// Parameters:
	//	hFSHandle		[in] File System handle.
	//	pstrFileName	[in] Target file name.
	//	pstrNewFileName	[in] New file name.
	//	pstrTargetPath	[in] Target path. If the path is NULL, 
	//						 the current folder is used. 
	//
	// Return values:
	//	CONA_OK
	//	ECONA_INVALID_HANDLE
	//	ECONA_INVALID_PARAMETER
	//	ECONA_CONNECTION_BUSY
	//	ECONA_CONNECTION_LOST
	//	ECONA_INVALID_DATA_DEVICE
	//	ECONA_MEMORY_FULL
	//	ECONA_CURRENT_FOLDER_NOT_FOUND
	//	ECONA_FOLDER_PATH_TOO_LONG
	//	ECONA_FILE_NAME_INVALID
	//	ECONA_FILE_NAME_TOO_LONG
	//	ECONA_FILE_NOT_FOUND
	//	ECONA_FILE_ALREADY_EXIST
	//	ECONA_FILE_COPYRIGHT_PROTECTED
	//	ECONA_FILE_NO_PERMISSION
	//	ECONA_FILE_BUSY
	//	ECONA_FILE_TYPE_NOT_SUPPORTED
	//  ECONA_FILE_EXIST
	//	ECONA_NOT_SUPPORTED_DEVICE
	//	ECONA_CANCELLED
	//	ECONA_FAILED_TIMEOUT
	//	ECONA_UNKNOWN_ERROR_DEVICE
	//	ECONA_NOT_INITIALIZED
	//	ECONA_NOT_ENOUGH_MEMORY
	//	ECONA_UNKNOWN_ERROR
	//	
		CONN_API CONARenameFile(FSHANDLE hFSHandle,
								const WCHAR* pstrFileName,
								const WCHAR* pstrNewFileName,
								const WCHAR* pstrTargetPath );
	//=========================================================

	//=========================================================
	// CONAReadFile
	//
	// Description:
	//	CONAReadFile reads a file from the device. The Connectivity
	//	API will allocate memory for the file data automatically. 
	//	The file data buffer must be released by using the 
	//	CONAFreeFileData function. If operation fails, returned 
	//	pFileData pointer is to NULL.
	//
	//	If the file is empty, returned pFileData pointer is a zero-
	//	length memory item and that must be released. In this case 
	//	dwFileSize is set to zero. 
	//
	//
	// Parameters:
	//	hFSHandle		  [in]  File System handle
	//	pFileInfo		  [in,out]  Target file info structure pointer
	//							In: File name (or File type) must be set. 
	//							Out: The Connectivity API sets the file 
	//							modified time stamp (if available), 
	//							file size (number of bytes in FileData), 
	//							file MIME type (if available) and 
	//							file attributes.
	//	ppFileData		  [out] Pointer to the pointer of the file data  
	//	dwLimitedReadSize [in]  Reads only the number of bytes from 
	//			the beginning of the file. Value MUST be 0 (zero) when 
	//			the whole file is targeted to be read.
	//	pstrTargetPath	  [in]  Target path. If the path is NULL, 
	//							the current folder is used. 
	//
	// Return values:
	//	CONA_OK
	//	ECONA_INVALID_HANDLE
	//	ECONA_INVALID_PARAMETER
	//	ECONA_CONNECTION_BUSY
	//	ECONA_CONNECTION_LOST
	//	ECONA_CURRENT_FOLDER_NOT_FOUND
	//	ECONA_FOLDER_PATH_TOO_LONG
	//	ECONA_FILE_NAME_INVALID
	//	ECONA_FILE_NOT_FOUND
	//	ECONA_FILE_COPYRIGHT_PROTECTED
	//	ECONA_FILE_NO_PERMISSION
	//	ECONA_FILE_BUSY
	//	ECONA_CANCELLED
	//	ECONA_NOT_SUPPORTED_DEVICE
	//	ECONA_FAILED_TIMEOUT
	//	ECONA_UNKNOWN_ERROR_DEVICE
	//	ECONA_NOT_INITIALIZED
	//	ECONA_UNKNOWN_ERROR
	//	
		CONN_API CONAReadFile(	FSHANDLE	hFSHandle,
								LPCONAPI_FILE_INFO pFileInfo,
								unsigned char**  ppFileData,
								DWORD dwLimitedReadSize,
								const WCHAR* pstrTargetPath);
	//=========================================================

	//=========================================================
	// CONAWriteFile
	//
	// Description:
	//	CONAWriteFile writes a file onto the device. The file 
	//	data buffer must be allocated by using the CONAAllocFileData 
	//	function, and afterwards the CONAWriteFile buffer must be 
	//	released by using the CONAFreeFileData function. 
	//
	//	If it is need to write an empty file to device, pFileData 
	//	pointer must be a zero-length memory item which is allocated 
	//	by using CONAAllocFileData function with value 0.
	//
	//	The tFileTime-struct is used to set modified time stamp to
	//	writed file. If the value is zero or invalid, PC's current time is used. 
	//
	//	If target folder includes same named file, it will be overwrited!
	//
	//	Note: No rollback option! Overwrited data cannot be restored!
	//
	// Parameters:
	//	hFSHandle		[in] File System handle
	//	pFileInfo		[in] Writed file info, File name and 
	//						 file size must be set. If file time is set
	//						 and value is valid, that time send to device. 
	//						 Otherwise PC's current time is used.
	//	pFileData		[in] Pointer to file data 
	//	pstrTargetPath	[in] Target path. If the path is NULL, 
	//						 the current folder is used. 
	//
	// Return values:
	//	CONA_OK
	//	ECONA_INVALID_HANDLE
	//	ECONA_INVALID_PARAMETER
	//	ECONA_CONNECTION_BUSY
	//	ECONA_CONNECTION_LOST
	//	ECONA_FILE_NAME_INVALID
	//	ECONA_INVALID_DATA_DEVICE
	//	ECONA_MEMORY_FULL
	//	ECONA_CURRENT_FOLDER_NOT_FOUND
	//	ECONA_FOLDER_PATH_TOO_LONG
	//	ECONA_FILE_NAME_INVALID
	//	ECONA_FILE_NAME_TOO_LONG
	//	ECONA_FILE_ALREADY_EXIST
	//	ECONA_FILE_TYPE_NOT_SUPPORTED
	//	ECONA_CANCELLED
	//	ECONA_NOT_SUPPORTED_DEVICE
	//	ECONA_FAILED_TIMEOUT
	//	ECONA_UNKNOWN_ERROR_DEVICE
	//	ECONA_NOT_INITIALIZED
	//	ECONA_UNKNOWN_ERROR
	//	
		CONN_API CONAWriteFile( FSHANDLE	hFSHandle,
								LPCONAPI_FILE_INFO pFileInfo,
								const unsigned char* pFileData,
								const WCHAR* pstrTargetPath );
	//=========================================================

	//=========================================================
	// CONACancel
	//
	// Description:
	//	Cancels the ongoing operation. If there is not a running 
	//	operation, the Cancel function fails with the error code 
	//  ECONA_NOTHING_TO_CANCEL.
	//
	// Parameters:
	//	hFSHandle		[in] File System handle
	//
	// Return values:
	//	CONA_OK
	//	ECONA_INVALID_HANDLE
	//	ECONA_NOTHING_TO_CANCEL
	//	ECONA_NOT_INITIALIZED
	//	ECONA_UNKNOWN_ERROR
	//
		CONN_API CONACancel( FSHANDLE hFSHandle );
	//=========================================================

	//=========================================================
	// CONAFreeFileInfoStructure 
	//
	// Description:
	//	CONAFreeFileInfoStructure frees a given list of CONAPI_FILE_INFO structs.
	//
	// Parameters:
	//	pFileInfo		[in] Pointer to a file data struct.
	//
	// Return values:
	//	CONA_OK
	//	ECONA_INVALID_POINTER
	//	ECONA_UNKNOWN_ERROR
	//
		CONN_API CONAFreeFileInfoStructure( LPCONAPI_FILE_INFO pFileInfo );		
	//=========================================================

	//=========================================================
	// CONAFreeFolderInfoStructure
	//
	// Description:
	//	CONAFreeFolderInfoStructure frees a given list of CONAPI_FOLDER_INFO structs.
	//
	// Parameters:
	//	pFolderInfo		[in] Pointer to  afolder data struct.
	//
	// Return values: 
	//	CONA_OK
	//	ECONA_INVALID_POINTER
	//	ECONA_UNKNOWN_ERROR
	//
		CONN_API CONAFreeFolderInfoStructure( LPCONAPI_FOLDER_INFO pFolderInfo );		
	//=========================================================

	//=========================================================
	// CONAAllocFileDataMemory
	//
	// Description:
	//	CONAAllocFileDataMemory function returns allocated memory 
	//	for file data.  The allocated memory format is an unsigned 
	//	char, and the memory must be freed by using the 
	//	CONAFreeFileDataMemory function.
	//
	//	If dwDataSize value is 0, function allocates a zero-length 
	//	memory item and returns a valid pointer to it.
	//
	// Parameters:
	//	dwDataSize			[in] Allocated memory size in bytes.
	//
	// Return values:
	//	Unsigned char* - allocated memory pointer. Returns NULL if it fails.
	//
		CONN_APIEX(unsigned char*) CONAAllocFileDataMemory( DWORD dwDataSize );
	//=========================================================

	//=========================================================
	// CONAFreeFileDataMemory
	//
	// Description:
	//	CONAFreeFileDataMemory frees file data memory.
	//
	// Parameters:
	//	pFileData			[in] Pointer to file data.
	//
	// Return values:
	//	CONA_OK
	//	ECONA_INVALID_POINTER
	//	ECONA_UNKNOWN_ERROR
	//
		CONN_API CONAFreeFileDataMemory( unsigned char* pFileData );
	//=========================================================

#endif

