/*
==============================================================================
* PC Suite Connectivity API 1.1
*
Filename    : ConnAPI.h
Description : API functions
Version     : 1.1

Copyright (c) 2005 Nokia Corporation.
This software, including but not limited to documentation and any related 
computer programs ("Software"), is protected by intellectual property rights 
of Nokia Corporation and/or its licensors. All rights are reserved. By using 
the Software you agree to the terms and conditions hereunder. If you do not 
agree you must cease using the software immediately.
Reproducing, disclosing, modifying, translating, or distributing any or all 
of the Software requires the prior written consent of Nokia Corporation. 
Nokia Corporation retains the right to make changes to the Software at any 
time without notice.

A copyright license is hereby granted to use of the Software to make, publish, 
distribute, sub-license and/or sell new Software utilizing this Software. 
The Software may not constitute the primary value of any new software utilizing 
this software. No other license to any other intellectual property rights of 
Nokia or a third party is granted. 

THIS SOFTWARE IS PROVIDED "AS IS" WITHOUT WARRANTY OF ANY KIND, EITHER EXPRESS 
OR IMPLIED, INCLUDING WITHOUT LIMITATION, ANY WARRANTY OF NON-INFRINGEMENT, 
MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. IN NO EVENT SHALL
NOKIA CORPORATION BE LIABLE FOR ANY DIRECT, INDIRECT, SPECIAL, INCIDENTAL, 
OR CONSEQUENTIAL LOSS OR DAMAGES, INCLUDING BUT NOT LIMITED TO, LOST PROFITS 
OR REVENUE, LOSS OF USE, COST OF SUBSTITUTE PROGRAM, OR LOSS OF DATA OR EQUIPMENT 
ARISING OUT OF THE USE OR INABILITY TO USE THE MATERIAL, EVEN IF 
NOKIA CORPORATION HAS BEEN ADVISED OF THE LIKELIHOOD OF SUCH DAMAGES OCCURRING. 
==============================================================================
*/

#ifndef _CONN_API_H_
#define _CONN_API_H_

///////////////////////////////////////////////////////////
// Connectivity API errors
///////////////////////////////////////////////////////////
	#include "CONAErrors.h"
///////////////////////////////////////////////////////////

///////////////////////////////////////////////////////////
// Connectivity API data definitions
///////////////////////////////////////////////////////////
	#include "CONADefinitions.h"
///////////////////////////////////////////////////////////

///////////////////////////////////////////////////////////
// Connectivity API methods
///////////////////////////////////////////////////////////

	//=========================================================
	// Current Connectivity API version
	//
		#define CONA_API_VERSION	11
	//=========================================================

	//=========================================================
	// CONAInitialize
	//
	// Description:
	//	CONAInitialize initializes the Connectivity API -library 
	//	and connects to the solution interfaces. This 
	//	function must be called before any other Connectivity API 
	//	functions, and it must be called once per every Connectivity API 
	//	instance. A multithreaded application needs to call this 
	//	function only once. 
	//	
	//	All successful calls of this method need corresponding number of 
	//  CONAUninitialize calls.
	//
	//  This Connectivity API supported version are 1.0 and 1.1 (the 
	//  value for that are 10 and 11). An API user must give a number 	
	//  value of the Connectivity API version in the parameter. 
	//  If the API user gives a bigger version number than what 
	//  the installed Connectivity API supports, the function fails 
	//  with the error code ECONA_UNSUPPORTED_API_VERSION.
	//  
	// Parameters:
	//	dwVersion		[in]     Version number, value should be CONA_API_VERSION 
	//	pstrManufacturer[in]     Target manufacturer string. If used, 
	//			only the target manufacturer devices are available. 
	//			E.g. the String for Nokia devices is "Nokia". 
	//			If the string is NULL, all devices are available.
	//	pValue			[in,out] Reserved for future use, the value must be NULL. 
	//
	// Return values:
	// CONA_OK
	// ECONA_INIT_FAILED
	// ECONA_UNSUPPORTED_API_VERSION
	// ECONA_NOT_SUPPORTED_MANUFACTURER
	// ECONA_INVALID_PARAMETER 
	// ECONA_INVALID_POINTER

		CONN_API CONAInitialize(DWORD dwVersion, const WCHAR* pstrManufacturer, LPVOID pValue);
	//=========================================================

	//=========================================================
	// CONAUninitialize
	//
	// Description:
	//	CONAUninitialize disconnects the Connectivity API from 
	//  the solution and frees the used resources. This 
	//  function must be called just before application termination.
	//
	//	All calls of this method need corresponding number of 
	//  successful CONAInitialize calls. Otherwise all resources
	//  and memories won't be released.
	//
	// Parameters:
	//	dwValue			[in] Reserved for future use, the value must be zero.  
	//
	// Return values:
	// CONA_OK
	// ECONA_NOT_INITIALIZED
	// ECONA_UNKNOWN_ERROR
	// ECONA_INVALID_PARAMETER 
	//
		CONN_API CONAUninitialize(DWORD dwValue);
	//=========================================================

	//=========================================================
	// CONAGetConnAPIVersion
	//
	// Description:
	//	CONAGetConnAPIVersion returns the installed Connectivity API 
	//	version number.
	//
	// Parameters:
	//	-
	//
	// Return values:
	// DWORD- function returns the Connectivity API version number. 
	//  The version number of this Connectivity API is 11 (1.1). 
	//
		CONN_API CONAGetConnAPIVersion();
	//=========================================================

///////////////////////////////////////////////////////////


///////////////////////////////////////////////////////////
// Device API methods
///////////////////////////////////////////////////////////
	#include "CONADeviceManagement.h"
///////////////////////////////////////////////////////////

///////////////////////////////////////////////////////////
// File System API methods
///////////////////////////////////////////////////////////
	#include "CONAFileSystem.h"
///////////////////////////////////////////////////////////


///////////////////////////////////////////////////////////
// Application installation API methods
///////////////////////////////////////////////////////////
	#include "CONAApplicationInstallation.h"
///////////////////////////////////////////////////////////


///////////////////////////////////////////////////////////
// Common methods
///////////////////////////////////////////////////////////

	//=========================================================
	// CONAAllocString
	//
	// Description:
	//	CONAAllocString allocates Unicode strings. Allocated 
	//  strings must be freed by using CONAFreeString. 
	//
	// Parameters:
	//	pstrString			[in] Pointer to a NULL terminated 
	//                           Unicode string for copying.
	//
	// Return values:
	//	WCHAR* - allocated memory pointer. Returns NULL if it fails.
	//
		CONN_APIEX(WCHAR*) CONAAllocString( WCHAR* pstrString );
	//=========================================================

	//=========================================================
	// CONAFreeString
	//
	// Description:
	//	CONAFreeString frees the allocated string.
	//
	// Parameters:
	//	pstrString			[in] Pointer to a string
	//
	// Return values:
	//	CONA_OK
	//	ECONA_INVALID_POINTER
	//	ECONA_UNKNOWN_ERROR
	//
		CONN_API CONAFreeString( WCHAR* pstrString );
	//=========================================================

///////////////////////////////////////////////////////////

#endif

